pub struct GetProofByHashResponse {
pub leaf_index: u64,
pub audit_path: Vec<String>,
}Fields
leaf_index: u64The 0-based index of the end entity corresponding to the “hash” parameter.
audit_path: Vec<String>An array of base64-encoded Merkle Tree nodes proving the inclusion of the chosen certificate.