pub struct GetSthResponse {
pub tree_size: u64,
pub timestamp: u64,
pub sha256_root_hash: String,
pub tree_head_signature: String,
}Fields
tree_size: u64The size of the tree, in entries, in decimal.
timestamp: u64The timestamp, in decimal.
sha256_root_hash: StringThe Merkle Tree Hash of the tree, in base64.
tree_head_signature: StringA TreeHeadSignature for the above data.